/*=============================================================================#
 # Copyright (c) 2012, 2021 Stephan Wahlbrink and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
 # which is available at https://www.apache.org/licenses/LICENSE-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0 OR Apache-2.0
 # 
 # Contributors:
 #     Stephan Wahlbrink <sw@wahlbrink.eu> - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.ecommons.waltable.command;

import org.eclipse.statet.ecommons.waltable.coordinate.Orientation;
import org.eclipse.statet.ecommons.waltable.layer.ILayer;
import org.eclipse.statet.ecommons.waltable.layer.ILayerDim;
import org.eclipse.statet.ecommons.waltable.layer.LayerUtil;


public abstract class AbstractDimPositionCommand implements ILayerCommand {
	
	
	private ILayerDim layerDim;
	
	private long position;
	
	
	protected AbstractDimPositionCommand(final ILayerDim layerDim, final long position) {
		this.layerDim= layerDim;
		this.position= position;
	}
	
	protected AbstractDimPositionCommand(final AbstractDimPositionCommand command) {
		this.layerDim= command.layerDim;
		this.position= command.position;
	}
	
	
	public final Orientation getOrientation() {
		return this.layerDim.getOrientation();
	}
	
	public final ILayerDim getDim() {
		return this.layerDim;
	}
	
	public long getPosition() {
		return this.position;
	}
	
	
	@Override
	public boolean convertToTargetLayer(final ILayer targetLayer) {
		final ILayerDim targetDim= targetLayer.getDim(getOrientation());
		if (this.layerDim == targetDim) {
			return true;
		}
		
		return convertToTargetLayer(this.layerDim, this.position, targetDim);
	}
	
	protected boolean convertToTargetLayer(final ILayerDim dim,
			final long position, final ILayerDim targetDim) {
		final long targetPosition= LayerUtil.convertPosition(dim, position, position, targetDim);
		if (targetPosition == ILayerDim.POSITION_NA) {
			return false;
		}
		
		this.layerDim= targetDim;
		this.position= targetPosition;
		return true;
	}
	
}
