/*=============================================================================#
 # Copyright (c) 2012, 2021 Original NatTable authors and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0
 # 
 # Contributors:
 #     Original NatTable authors and others - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.ecommons.waltable.data;

import org.eclipse.core.runtime.IProgressMonitor;

import org.eclipse.statet.ecommons.waltable.layer.DataLayer;


/**
 * Provide data to the table.
 * 
 * @see DataLayer
 * @see ListDataProvider
 */
public interface IDataProvider {
	
	
	int FORCE_SYNC= 1 << 0;
	
	
	long getColumnCount();
	
	long getRowCount();
	
	
	/**
	 * Gets the value at the given column and row index.
	 *
	 * @param columnIndex
	 * @param rowIndex
	 * @param flags
	 * @param monitor
	 * @return the data value associated with the specified cell
	 */
	Object getDataValue(long columnIndex, long rowIndex,
			int flags, IProgressMonitor monitor);
	
	/**
	 * Sets the value at the given column and row index. Optional operation. Should throw UnsupportedOperationException
	 * if this operation is not supported.
	 *
	 * @param columnIndex
	 * @param rowIndex
	 * @param newValue
	 */
	void setDataValue(long columnIndex, long rowIndex, Object newValue);
	
}
