/*=============================================================================#
 # Copyright (c) 2012, 2021 Original NatTable authors and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0
 # 
 # Contributors:
 #     Original NatTable authors and others - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.ecommons.waltable.grid.layer;

import static org.eclipse.statet.ecommons.waltable.coordinate.Orientation.VERTICAL;

import org.eclipse.statet.ecommons.waltable.layer.ILayer;
import org.eclipse.statet.ecommons.waltable.layer.config.DefaultRowHeaderLayerConfiguration;
import org.eclipse.statet.ecommons.waltable.painter.layer.ILayerPainter;
import org.eclipse.statet.ecommons.waltable.selection.SelectionLayer;
import org.eclipse.statet.ecommons.waltable.style.SelectionStyleLabels;


/**
 * Layer for the row headers of the grid layer
 */
public class RowHeaderLayer extends AbstractPositionHeaderLayer {
	
	
	/**
	 * Creates a row header layer using the default configuration and painter
	 * 
	 * @param baseLayer
	 *            The data provider for this layer
	 * @param verticalLayerDependency
	 *            The layer to link the vertical dimension to, typically the body layer
	 * @param selectionLayer
	 *            The selection layer required to respond to selection events
	 */
	public RowHeaderLayer(final ILayer baseLayer, final ILayer verticalLayerDependency, final SelectionLayer selectionLayer) {
		this(baseLayer, verticalLayerDependency, selectionLayer, true);
	}
	
	public RowHeaderLayer(final ILayer baseLayer, final ILayer verticalLayerDependency, final SelectionLayer selectionLayer,
			final boolean useDefaultConfiguration) {
		this(baseLayer, verticalLayerDependency, selectionLayer, useDefaultConfiguration, null);
	}
	
	/**
	 * @param baseLayer
	 *            The data provider for this layer
	 * @param verticalLayerDependency
	 *            The layer to link the vertical dimension to, typically the body layer
	 * @param selectionLayer
	 *            The selection layer required to respond to selection events
	 * @param useDefaultConfiguration
	 *            If default configuration should be applied to this layer
	 * @param layerPainter
	 *            The painter for this layer or <code>null</code> to use the painter of the base layer
	 */
	public RowHeaderLayer(final ILayer baseLayer, final ILayer verticalLayerDependency,
			final SelectionLayer selectionLayer, final boolean useDefaultConfiguration, final ILayerPainter layerPainter) {
		super(baseLayer, VERTICAL, verticalLayerDependency,
				selectionLayer, SelectionStyleLabels.ROW_FULLY_SELECTED_STYLE,
				layerPainter );
		
		registerCommandHandlers();
		
		if (useDefaultConfiguration) {
			addConfiguration(new DefaultRowHeaderLayerConfiguration());
		}
	}
	
	
}
