/*=============================================================================#
 # Copyright (c) 2012, 2021 Edwin Park and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0
 # 
 # Contributors:
 #     Edwin Park - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.ecommons.waltable.layer.cell;

import org.eclipse.core.runtime.IProgressMonitor;

import org.eclipse.statet.ecommons.waltable.layer.ILayer;
import org.eclipse.statet.ecommons.waltable.layer.LabelStack;
import org.eclipse.statet.ecommons.waltable.style.DisplayMode;


public class ForwardLayerCell extends LayerCell {
	
	
	private final ILayerCell underlyingCell;
	
	
	public ForwardLayerCell(final ILayer layer,
			final ILayerCellDim horizontalDim, final ILayerCellDim verticalDim,
			final ILayerCell underlyingCell) {
		super(layer, horizontalDim, verticalDim);
		
		this.underlyingCell= underlyingCell;
	}
	
	
	public ILayerCell getUnderlyingCell() {
		return this.underlyingCell;
	}
	
	@Override
	public DisplayMode getDisplayMode() {
		return this.underlyingCell.getDisplayMode();
	}
	
	@Override
	public LabelStack getConfigLabels() {
		return this.underlyingCell.getConfigLabels();
	}
	
	
	@Override
	public Object getDataValue(final int flags, final IProgressMonitor monitor) {
		return this.underlyingCell.getDataValue(flags, monitor);
	}
	
}
