/*=============================================================================#
 # Copyright (c) 2012, 2021 Original NatTable authors and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0
 # 
 # Contributors:
 #     Original NatTable authors and others - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.ecommons.waltable.resize;

import org.eclipse.statet.ecommons.waltable.command.AbstractLayerCommandHandler;
import org.eclipse.statet.ecommons.waltable.coordinate.LRangeList;
import org.eclipse.statet.ecommons.waltable.layer.ILayerDim;
import org.eclipse.statet.ecommons.waltable.layer.LayerUtil;
import org.eclipse.statet.ecommons.waltable.selection.SelectionLayer;


public class InitializeAutoResizeCommandHandler extends AbstractLayerCommandHandler<InitializeAutoResizeCommand> {
	
	
	private final SelectionLayer selectionLayer;
	
	
	public InitializeAutoResizeCommandHandler(final SelectionLayer selectionLayer) {
		this.selectionLayer= selectionLayer;
	}
	
	@Override
	public Class<InitializeAutoResizeCommand> getCommandClass() {
		return InitializeAutoResizeCommand.class;
	}
	
	
	@Override
	protected boolean doCommand(final InitializeAutoResizeCommand initCommand) {
		final ILayerDim layerDim= initCommand.getDim();
		final long position= initCommand.getPosition();
		final LRangeList positions;
		
		final long selectionPosition= LayerUtil.convertPosition(layerDim,
				position, position, this.selectionLayer.getDim(layerDim.getOrientation()) );
		if (selectionPosition != ILayerDim.POSITION_NA
				&& this.selectionLayer.isPositionFullySelected(layerDim.getOrientation(), position) ) {
			positions= this.selectionLayer.getFullySelectedPositions(layerDim.getOrientation());
			
			this.selectionLayer.doCommand(new AutoResizePositionsCommand(
					this.selectionLayer.getDim(layerDim.getOrientation()), positions));
		}
		else {
			positions= new LRangeList(position);
			
			layerDim.getLayer().doCommand(new AutoResizePositionsCommand(layerDim, positions));
		}
		
		// Fire command carrying the selected columns
		return true;
	}
	
}
