/*=============================================================================#
 # Copyright (c) 2012, 2021 Original NatTable authors and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0
 # 
 # Contributors:
 #     Original NatTable authors and others - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.ecommons.waltable.resize;

import java.util.ArrayList;
import java.util.Collection;

import org.eclipse.statet.ecommons.waltable.coordinate.LRange;
import org.eclipse.statet.ecommons.waltable.layer.ILayer;
import org.eclipse.statet.ecommons.waltable.layer.event.RowStructuralChangeEvent;
import org.eclipse.statet.ecommons.waltable.layer.event.StructuralDiff;
import org.eclipse.statet.ecommons.waltable.layer.event.StructuralDiff.DiffTypeEnum;


public class RowResizeEvent extends RowStructuralChangeEvent {

	public RowResizeEvent(final ILayer layer, final long rowPosition) {
		super(layer, new LRange(rowPosition));
	}
	
	public RowResizeEvent(final ILayer layer, final LRange rowPositionRange) {
		super(layer, rowPositionRange);
	}
	
	protected RowResizeEvent(final RowResizeEvent event) {
		super(event);
	}
	
	@Override
	public RowResizeEvent cloneEvent() {
		return new RowResizeEvent(this);
	}
	
	@Override
	public Collection<StructuralDiff> getRowDiffs() {
		final Collection<StructuralDiff> rowDiffs= new ArrayList<>();
		
		for (final LRange lRange : getRowPositionRanges()) {
			new StructuralDiff(DiffTypeEnum.CHANGE, lRange, lRange);
		}
		
		return rowDiffs;
	}
	
}
