/*=============================================================================#
 # Copyright (c) 2010, 2021 Stephan Wahlbrink and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
 # which is available at https://www.apache.org/licenses/LICENSE-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0 OR Apache-2.0
 # 
 # Contributors:
 #     Stephan Wahlbrink <sw@wahlbrink.eu> - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.ecommons.waltable.viewport;

import org.eclipse.statet.ecommons.waltable.command.AbstractLayerCommandHandler;
import org.eclipse.statet.ecommons.waltable.coordinate.Direction;


public class ScrollStepCommandHandler extends AbstractLayerCommandHandler<ScrollStepCommand> {
	
	
	private final ViewportLayer viewportLayer;
	
	
	public ScrollStepCommandHandler(final ViewportLayer viewportLayer) {
		this.viewportLayer= viewportLayer;
	}
	
	@Override
	public Class<ScrollStepCommand> getCommandClass() {
		return ScrollStepCommand.class;
	}
	
	
	@Override
	protected boolean doCommand(final ScrollStepCommand command) {
		final Direction direction= command.getDirection();
		final IViewportDim dim= this.viewportLayer.getDim(direction.getOrientation());
		if (direction.isBackward()) {
			dim.scrollBackwardByStep();
		}
		else /*if (direction.isForward())*/ {
			dim.scrollForwardByStep();
		}
		return true;
	}
	
}
