/*=============================================================================#
 # Copyright (c) 2014, 2021 Stephan Wahlbrink and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
 # which is available at https://www.apache.org/licenses/LICENSE-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0 OR Apache-2.0
 # 
 # Contributors:
 #     Stephan Wahlbrink <sw@wahlbrink.eu> - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.ecommons.collections;

import java.util.Comparator;


public abstract class CategoryElementComparator<C, E> implements Comparator<E> {
	
	
	protected CategoryElementComparator() {
	}
	
	
	@Override
	public final int compare(final E o1, final E o2) {
		final int d= compareCategory(getCategory(o1), getCategory(o2));
		if (d != 0) {
			return d;
		}
		return compareElement(o1, o2);
	}
	
	public abstract C getCategory(E element);
	
	public abstract int compareCategory(C category1, C category2);
	
	public abstract int compareElement(E element1, E element2);
	
}
