/*=============================================================================#
 # Copyright (c) 2015, 2021 Stephan Wahlbrink and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
 # which is available at https://www.apache.org/licenses/LICENSE-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0 OR Apache-2.0
 # 
 # Contributors:
 #     Stephan Wahlbrink <sw@wahlbrink.eu> - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.ecommons.text.core;

import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.IDocumentPartitioningListenerExtension2;

import org.eclipse.statet.jcommons.lang.NonNullByDefault;
import org.eclipse.statet.jcommons.lang.Nullable;

import org.eclipse.statet.internal.ecommons.text.core.DocumentEnhancementImpl;


@NonNullByDefault
public interface DocumentEnhancement {
	
	
	void addPrePartitioningListener(IDocumentPartitioningListenerExtension2 listener);
	void removePrePartitioningListener(IDocumentPartitioningListenerExtension2 listener);
	
	@Nullable Object getData(String key);
	void setData(String key, @Nullable Object value);
	
	
	static void setup(final IDocument document) {
		DocumentEnhancementImpl.setup(document);
	}
	
	static DocumentEnhancement get(final IDocument document) {
		return DocumentEnhancementImpl.get(document);
	}
	
}
