/*=============================================================================#
 # Copyright (c) 2009, 2021 Stephan Wahlbrink and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
 # which is available at https://www.apache.org/licenses/LICENSE-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0 OR Apache-2.0
 # 
 # Contributors:
 #     Stephan Wahlbrink <sw@wahlbrink.eu> - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.ecommons.ui;

import org.eclipse.jface.resource.ImageRegistry;
import org.eclipse.swt.graphics.Point;

import org.eclipse.statet.ecommons.ui.util.UIResources;
import org.eclipse.statet.internal.ecommons.ui.UIMiscellanyPlugin;


public class SharedUIResources extends UIResources {
	
	
	public static final String BUNDLE_ID= UIMiscellanyPlugin.BUNDLE_ID;
	
	
	public static final String EDIT_COPYPASTE_MENU_ID= "edit.copypaste"; //$NON-NLS-1$
	
	
	public static final String NEW_PAGE_COMMAND_ID = "org.eclipse.statet.workbench.commands.NewPage"; //$NON-NLS-1$
	public static final String CLOSE_PAGE_COMMAND_ID = "org.eclipse.statet.workbench.commands.ClosePage"; //$NON-NLS-1$
	public static final String CLOSE_ALL_PAGES_COMMAND_ID = "org.eclipse.statet.workbench.commands.CloseAllPages"; //$NON-NLS-1$
	
	/** equal to org.eclipse.ui.texteditor.IWorkbenchActionDefinitionIds#FIND_NEXT */
	public static final String FIND_NEXT_COMMAND_ID = "org.eclipse.ui.edit.findNext"; //$NON-NLS-1$
	/** equal to org.eclipse.ui.texteditor.IWorkbenchActionDefinitionIds#FIND_PREVIOUS */
	public static final String FIND_PREVIOUS_COMMAND_ID = "org.eclipse.ui.edit.findPrevious"; //$NON-NLS-1$
	
	
	public static final String PLACEHOLDER_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/obj/dummy"; //$NON-NLS-1$
	
	public static final String OBJ_USER_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/obj/user"; //$NON-NLS-1$
	
	public static final String OBJ_LINE_MATCH_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/obj/line_match"; //$NON-NLS-1$
	
	public static final String OBJ_MAIN_TAB_ID= UIMiscellanyPlugin.BUNDLE_ID + "/image/obj/main_tab"; //$NON-NLS-1$
	
	public static final String OVR_DEFAULT_MARKER_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/ovr/default_marker"; //$NON-NLS-1$
	public static final String OVR_GREEN_LIGHT_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/ovr/light-green"; //$NON-NLS-1$
	public static final String OVR_YELLOW_LIGHT_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/ovr/light-yellow"; //$NON-NLS-1$
	
	public static final String OVR_INFO_IMAGE_ID= UIMiscellanyPlugin.BUNDLE_ID + "/image/ovr/info"; //$NON-NLS-1$
	public static final String OVR_WARNING_IMAGE_ID= UIMiscellanyPlugin.BUNDLE_ID + "/image/ovr/warning"; //$NON-NLS-1$
	public static final String OVR_ERROR_IMAGE_ID= UIMiscellanyPlugin.BUNDLE_ID + "/image/ovr/error"; //$NON-NLS-1$
	
	public static final String OVR_DEPRECATED_IMAGE_ID= UIMiscellanyPlugin.BUNDLE_ID + "/image/ovr/deprecated"; //$NON-NLS-1$
	
	public static final String LOCTOOL_FILTER_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/filter_view"; //$NON-NLS-1$
	public static final String LOCTOOLD_FILTER_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctoold/filter_view"; //$NON-NLS-1$
	public static final String LOCTOOL_DISABLE_FILTER_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/disable-filter"; //$NON-NLS-1$
	
	public static final String LOCTOOL_SORT_ALPHA_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/sort.alpha"; //$NON-NLS-1$
	public static final String LOCTOOL_SORT_SCORE_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/sort.score"; //$NON-NLS-1$
	
	public static final String LOCTOOL_CASESENSITIVE_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/casesensitive"; //$NON-NLS-1$
	
	public static final String LOCTOOL_EXPANDALL_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/expandall"; //$NON-NLS-1$
	public static final String LOCTOOL_COLLAPSEALL_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/collapseall"; //$NON-NLS-1$
	
	public static final String LOCTOOL_SCROLLLOCK_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/scrolllock"; //$NON-NLS-1$
	
	public static final String LOCTOOL_CLEARSEARCH_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/clearsearch"; //$NON-NLS-1$
	public static final String LOCTOOLD_CLEARSEARCH_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctoold/clearsearch"; //$NON-NLS-1$
	
	public static final String LOCTOOL_SYNCHRONIZED_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/synchronized"; //$NON-NLS-1$
	
	public static final String LOCTOOL_FAVORITES_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctoolh/favorites"; //$NON-NLS-1$
	
	public static final String LOCTOOL_CLOSETRAY_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/close"; //$NON-NLS-1$
	public static final String LOCTOOL_CLOSETRAY_H_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctoolh/close"; //$NON-NLS-1$
	
	public static final String LOCTOOL_LEFT_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/left"; //$NON-NLS-1$
	public static final String LOCTOOL_LEFT_H_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctoolh/left"; //$NON-NLS-1$
	public static final String LOCTOOL_RIGHT_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/right"; //$NON-NLS-1$
	public static final String LOCTOOL_RIGHT_H_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctoolh/right"; //$NON-NLS-1$
	
	public static final String LOCTOOL_UP_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/up"; //$NON-NLS-1$
	public static final String LOCTOOL_UP_H_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctoolh/up"; //$NON-NLS-1$
	public static final String LOCTOOL_DOWN_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/down"; //$NON-NLS-1$
	public static final String LOCTOOL_DOWN_H_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctoolh/down"; //$NON-NLS-1$
	
	public static final String LOCTOOL_CHANGE_PAGE_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/change_page"; //$NON-NLS-1$
	public static final String LOCTOOL_PIN_PAGE_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctool/pin_page"; //$NON-NLS-1$
	public static final String LOCTOOLD_PIN_PAGE_IMAGE_ID = UIMiscellanyPlugin.BUNDLE_ID + "/image/loctoold/pin_page"; //$NON-NLS-1$
	
	
	/**
	 * The image registry of ECommonsUI
	 * 
	 * @return the image registry
	 */
	public static ImageRegistry getImages() {
		return UIMiscellanyPlugin.getInstance().getImageRegistry();
	}
	
	
	public static final SharedUIResources INSTANCE= new SharedUIResources();
	
	private final Point iconDefaultSize= new Point(16, 16);
	
	
	private SharedUIResources() {
		super(UIMiscellanyPlugin.getInstance().getImageRegistry());
	}
	
	
	public Point getIconDefaultSize() {
		return this.iconDefaultSize;
	}
	
}
