/*=============================================================================#
 # Copyright (c) 2018, 2021 Stephan Wahlbrink and others.
 # 
 # This program and the accompanying materials are made available under the
 # terms of the Eclipse Public License 2.0 which is available at
 # https://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
 # which is available at https://www.apache.org/licenses/LICENSE-2.0.
 # 
 # SPDX-License-Identifier: EPL-2.0 OR Apache-2.0
 # 
 # Contributors:
 #     Stephan Wahlbrink <sw@wahlbrink.eu> - initial API and implementation
 #=============================================================================*/

package org.eclipse.statet.internal.jcommons.collections;

import java.util.Arrays;
import java.util.Spliterator;
import java.util.Spliterators;
import java.util.stream.LongStream;
import java.util.stream.StreamSupport;

import org.eclipse.statet.jcommons.collections.LongList;
import org.eclipse.statet.jcommons.lang.NonNullByDefault;
import org.eclipse.statet.jcommons.lang.Nullable;


@NonNullByDefault
public class ImLongArrayList extends AbstractImLongList {
	
	
	private final long[] array;
	
	
	public ImLongArrayList(final long[] array) {
		this.array= array;
	}
	
	
	@Override
	public int size() {
		return this.array.length;
	}
	
	@Override
	public boolean isEmpty() {
		return (this.array.length == 0);
	}
	
	@Override
	public boolean contains(final long element) {
		return (indexOf(element) >= 0);
	}
	
	@Override
	public long getAt(final int index) {
		if (index < 0 || index >= this.array.length) {
			throw new IndexOutOfBoundsException("index= " + index); //$NON-NLS-1$
		}
		return this.array[index];
	}
	
	@Override
	public int indexOf(final long element) {
		for (int i= 0; i < this.array.length; i++) {
			if (this.array[i] == element) {
				return i;
			}
		}
		return -1;
	}
	
	@Override
	public int lastIndexOf(final long element) {
		for (int i= this.array.length - 1; i >= 0; i--) {
			if (this.array[i] == element) {
				return i;
			}
		}
		return -1;
	}
	
	
	@Override
	public LongStream stream() {
		return StreamSupport.longStream(Spliterators.spliterator(this.array,
				Spliterator.ORDERED | Spliterator.IMMUTABLE ), false );
	}
	
	
	@Override
	public long[] toArray() {
		return Arrays.copyOf(this.array, this.array.length);
	}
	
	
	@Override
	public int hashCode() {
		int hashCode= 7;
		for (int i= 0; i < this.array.length; i++) {
			hashCode= 31 * hashCode + Long.hashCode(this.array[i]);
		}
		return hashCode;
	}
	
	@Override
	public boolean equals(final @Nullable Object obj) {
		if (obj == this) {
			return true;
		}
		if (obj instanceof LongList) {
			final LongList other= (LongList)obj;
			if (this.array.length != other.size()) {
				return false;
			}
			for (int i= 0; i < this.array.length; i++) {
				if (this.array[i] != other.getAt(i)) {
					return false;
				}
			}
			return true;
		}
		return false;
	}
	
	@Override
	public String toString() {
		return Arrays.toString(this.array);
	}
	
}
